/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QGraphicsScene>
#include <QGraphicsSceneMouseEvent>
#include <QPainter>
#include <QStyleOption>
#include <QColor>
#include <QPen>
#include <QtDebug>

#include <math.h>

#include  "con.h"
#include "Rslt.h"
#include  "Szrt.h"
#include "Flult.h"
#include "tslabels.h"

/*!
 * @praise Vishnu
 */
szrt::szrt(felu *fldlgz,rslt *alkt)
	: QGraphicsEllipseItem(),korrkt(fldlgz)
<%
	cel=alkt;

	setZValue(123);

	QPen mrtdt;
	mrtdt.setWidth(1);
	setPen(mrtdt);

	QRectF vnl;
	vnl.setTopLeft(QPointF(0,0));
	vnl.setWidth(20);
	vnl.setHeight(20);
	setRect(vnl);

	setBrush(QColor(255,255,0));

	setPos(QPointF(-30,0));
	setParentItem(cel);
%>

void szrt::paint(QPainter *jlzpnt,const QStyleOptionGraphicsItem *adelk,QWidget * irnyjl)
<%
        QGraphicsEllipseItem::paint(jlzpnt,adelk,irnyjl);
        jlzpnt->drawText(boundingRect().translated(0,1),Qt::AlignCenter,cel->rabir);
%>

